@@ -637,6 +637,9 @@ class Generator:
     def introducer_sql(self, expression: exp.Introducer) -> str:
         return f"{self.sql(expression, 'this')} {self.sql(expression, 'expression')}"
 
+    def pseudotype_sql(self, expression: exp.PseudoType) -> str:
+        return expression.name.upper()
+
     def rowformatdelimitedproperty_sql(self, expression: exp.RowFormatDelimitedProperty) -> str:
         fields = expression.args.get("fields")
         fields = f" FIELDS TERMINATED BY {fields}" if fields else ""
@@ -893,13 +896,15 @@ class Generator:
     def query_modifiers(self, expression: exp.Expression, *sqls: str) -> str:
         return csv(
             *sqls,
-            *[self.sql(sql) for sql in expression.args.get("joins", [])],
-            *[self.sql(sql) for sql in expression.args.get("laterals", [])],
+            *[self.sql(sql) for sql in expression.args.get("joins") or []],
+            *[self.sql(sql) for sql in expression.args.get("laterals") or []],
             self.sql(expression, "where"),
             self.sql(expression, "group"),
             self.sql(expression, "having"),
             self.sql(expression, "qualify"),
-            self.sql(expression, "window"),
+            self.seg("WINDOW ") + self.expressions(expression, "windows", flat=True)
+            if expression.args.get("windows")
+            else "",
             self.sql(expression, "distribute"),
             self.sql(expression, "sort"),
             self.sql(expression, "cluster"),
@@ -1010,11 +1015,7 @@ class Generator:
         spec_sql = " " + self.window_spec_sql(spec) if spec else ""
 
         alias = self.sql(expression, "alias")
-
-        if expression.arg_key == "window":
-            this = this = f"{self.seg('WINDOW')} {this} AS"
-        else:
-            this = f"{this} OVER"
+        this = f"{this} {'AS' if expression.arg_key == 'windows' else 'OVER'}"
 
         if not partition and not order and not spec and alias:
             return f"{this} {alias}"
